@@ -1,5 +1,5 @@
 package Util::Medley::Crypt;
-$Util::Medley::Crypt::VERSION = '0.013';
+$Util::Medley::Crypt::VERSION = '0.014';
 use Modern::Perl;
 use Moose;
 use namespace::autoclean;
@@ -14,7 +14,7 @@ Util::Medley::Crypt - Class for simple encrypt/descrypt of strings.
 
 =head1 VERSION
 
-version 0.013
+version 0.014
 
 =cut
 
@@ -66,6 +66,14 @@ All methods confess on error.
 Key to use for encrypting/decrypting methods when one isn't provided through
 the method calls.
 
+=over
+
+=item type: Str
+
+=item env var: MEDLEY_CRYPT_KEY
+
+=back
+
 =cut
 
 has key =>(
@@ -166,7 +174,7 @@ multi method encryptStr (Str :$str!,
 	    			   	 Str :$key) {
 
 	$key = $self->_getKey($key);
-
+    
     my $cipher = Crypt::CBC->new(-key => $key, -cipher => 'Blowfish');
     return $cipher->encrypt_hex($str);
 }
@@ -184,10 +192,15 @@ multi method encryptStr (Str $str,
 #################################################
 
 method _getKey (Str|Undef $key) {
-
+	
 	if ( !$key ) {
 		if ( !$self->key ) {
-			confess "must provide key";
+			if ($ENV{MEDLEY_CRYPT_KEY}){
+				return 	$ENV{MEDLEY_CRYPT_KEY};
+			}
+			else {
+				confess "must provide key";
+			}
 		}
 
 		return $self->key;
